@@ -1,5 +1,5 @@
 package Net::SPID::SAML;
-$Net::SPID::SAML::VERSION = '0.13';
+$Net::SPID::SAML::VERSION = '0.14';
 use Moo;
 
 use Carp;
@@ -58,7 +58,7 @@ sub get_button {
     
     my $html = '';
     foreach my $idp_id (sort keys %{$self->_idp}) {
-        $html .= sprintf qq!<p><a href="%s">Log In (%s)</a></p>\n!,
+        $html .= sprintf qq!<p><a class="btn btn-primary" href="%s">Login with SPID</a> <small>(%s)</small></p>\n!,
             $url_cb->($idp_id), $idp_id;
     }
     return $html;
@@ -233,7 +233,7 @@ Net::SPID::SAML
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
